@@ -2,6 +2,7 @@
 import sys, os
 
 def cythonize(source,
+              output=None,
               includes=(),
               destdir_c=None,
               destdir_h=None,
@@ -13,14 +14,20 @@ def cythonize(source,
     from Cython.Compiler import Options
     cwd = os.getcwd()
     try:
-        name, ext = os.path.splitext(source)
-        outputs_c = [name+'.c']
-        outputs_h = [name+'.h', name+'_api.h']
+        if output is None:
+            name, _ = os.path.splitext(source)
+            output = name + '.c'
+        else:
+            name, _ = os.path.splitext(output)
+        outputs_c = [output]
+        outputs_h = [name + '.h', name + '_api.h']
         # change working directory
         if wdir:
             os.chdir(wdir)
         # run Cython on source
         options = CompilationOptions(default_options)
+        if Options.directive_types['language_level'] is str:
+            options.language_level = '3str'
         options.output_file = outputs_c[0]
         options.include_path = list(includes)
         Options.generate_cleanup_code = 3
@@ -63,6 +70,7 @@ def cythonize(source,
 if __name__ == "__main__":
     sys.exit(
         cythonize('petsc4py.PETSc.pyx',
+                  'petsc4py.PETSc.c',
                   includes=['include'],
                   destdir_h=os.path.join('include', 'petsc4py'),
                   wdir='src')
