@@ -7,7 +7,7 @@
 PETSC_STATIC_INLINE
 PyObject *PyPetscScalar_FromPetscScalar(PetscScalar s)
 {
-#if defined(PETSC_USE_SCALAR_COMPLEX)
+#if defined(PETSC_USE_COMPLEX)
   double a = (double)PetscRealPart(s);
   double b = (double)PetscImaginaryPart(s);
   return PyComplex_FromDoubles(a, b);
@@ -19,7 +19,7 @@ PyObject *PyPetscScalar_FromPetscScalar(PetscScalar s)
 PETSC_STATIC_INLINE
 PetscScalar PyPetscScalar_AsPetscScalar(PyObject *o)
 {
-#if defined(PETSC_USE_SCALAR_COMPLEX)
+#if defined(PETSC_USE_COMPLEX)
   Py_complex cval = PyComplex_AsCComplex(o);
   PetscReal a = (PetscReal)cval.real;
   PetscReal b = (PetscReal)cval.imag;
