@@ -2,6 +2,7 @@ from petsc4py import PETSc
 import unittest
 
 import numpy as N
+import numpy as np
 
 def mkgraph(comm, m, n):
     start = m*n * comm.rank
@@ -164,12 +165,54 @@ class BaseTestMatAnyAIJ(object):
             self.assertTrue(N.allclose(aj[ai[i]:ai[i+1]], cols))
             self.assertTrue(N.allclose(av[ai[i]:ai[i+1]], vals))
 
-    #def testConvertToAIJ(self):
-    #    self._preallocate()
-    #    self._set_values_ijv()
-    #    A = self.A
-    #    A.assemble()
-    #    A.convert('aij')
+    def testConvertToSAME(self):
+        self._preallocate()
+        self._set_values_ijv()
+        A = self.A
+        A.assemble()
+        A.convert('same')
+
+    def testConvertToDENSE(self):
+        self._preallocate()
+        self._set_values_ijv()
+        A = self.A
+        A.assemble()
+        x, y = A.getVecs()
+        x.setRandom()
+        z = y.duplicate()
+        A.mult(x, y)
+        if A.type.endswith('sbaij'): return
+        B = PETSc.Mat()
+        A.convert('dense', B)  # initial
+        B.mult(x, z)
+        self.assertTrue(np.allclose(y.array, z.array))
+        A.convert('dense', B)  # reuse
+        B.mult(x, z)
+        self.assertTrue(np.allclose(y.array, z.array))
+        A.convert('dense')     # inplace
+        A.mult(x, z)
+        self.assertTrue(np.allclose(y.array, z.array))
+
+    def testConvertToAIJ(self):
+        self._preallocate()
+        self._set_values_ijv()
+        A = self.A
+        A.assemble()
+        x, y = A.getVecs()
+        x.setRandom()
+        z = y.duplicate()
+        A.mult(x, y)
+        if A.type.endswith('sbaij'): return
+        B = PETSc.Mat()
+        A.convert('aij', B)  # initial
+        B.mult(x, z)
+        self.assertTrue(np.allclose(y.array, z.array))
+        A.convert('aij', B)  # reuse
+        B.mult(x, z)
+        self.assertTrue(np.allclose(y.array, z.array))
+        A.convert('aij')     # inplace
+        A.mult(x, z)
+        self.assertTrue(np.allclose(y.array, z.array))
 
     def testGetDiagonalBlock(self):
         self._preallocate()
@@ -204,7 +247,7 @@ class BaseTestMatAnyAIJ(object):
             tmp[i-s,:,:] = N.linalg.inv(vals)
         self.assertTrue(N.allclose(ibdiag, tmp))
 
-    def testGetSubMatrix(self):
+    def testCreateSubMatrix(self):
         if 'baij' in self.A.getType(): return # XXX
         self._preallocate()
         self._set_values_ijv()
@@ -218,17 +261,17 @@ class BaseTestMatAnyAIJ(object):
         rows = PETSc.IS().createGeneral(rows, comm=self.A.getComm())
         cols = PETSc.IS().createGeneral(cols, comm=self.A.getComm())
         #
-        S = self.A.getSubMatrix(rows, None)
+        S = self.A.createSubMatrix(rows, None)
         S.zeroEntries()
-        self.A.getSubMatrix(rows, None, S)
+        self.A.createSubMatrix(rows, None, S)
         S.destroy()
         #
-        S = self.A.getSubMatrix(rows, cols)
+        S = self.A.createSubMatrix(rows, cols)
         S.zeroEntries()
-        self.A.getSubMatrix(rows, cols, S)
+        self.A.createSubMatrix(rows, cols, S)
         S.destroy()
 
-    def testGetSubMatrices(self):
+    def testCreateSubMatrices(self):
         if 'baij' in self.A.getType(): return # XXX
         self._preallocate()
         self._set_values_ijv()
@@ -241,32 +284,33 @@ class BaseTestMatAnyAIJ(object):
         rows = PETSc.IS().createGeneral(rows, comm=self.A.getComm())
         cols = PETSc.IS().createGeneral(cols, comm=self.A.getComm())
         #
-        (S,) = self.A.getSubMatrices(rows, cols)
+        (S,) = self.A.createSubMatrices(rows, cols)
         S.zeroEntries()
-        self.A.getSubMatrices(rows, cols, submats=[S])
+        self.A.createSubMatrices(rows, cols, submats=[S])
         S.destroy()
         #
-        (S1,) = self.A.getSubMatrices([rows], [cols])
-        (S2,) = self.A.getSubMatrices([rows], [cols])
+        (S1,) = self.A.createSubMatrices([rows], [cols])
+        (S2,) = self.A.createSubMatrices([rows], [cols])
         self.assertTrue(S1.equal(S2))
         S2.zeroEntries()
-        self.A.getSubMatrices([rows], [cols], [S2])
+        self.A.createSubMatrices([rows], [cols], [S2])
         self.assertTrue(S1.equal(S2))
         S1.destroy()
         S2.destroy()
         #
         if 'seq' not in self.A.getType(): return # XXX
-        S1, S2 = self.A.getSubMatrices([rows, rows], [cols, cols])
+        S1, S2 = self.A.createSubMatrices([rows, rows], [cols, cols])
         self.assertTrue(S1.equal(S2))
         S1.zeroEntries()
         S2.zeroEntries()
-        self.A.getSubMatrices([rows, rows], [cols, cols], [S1, S2])
+        self.A.createSubMatrices([rows, rows], [cols, cols], [S1, S2])
         self.assertTrue(S1.equal(S2))
         S1.destroy()
         S2.destroy()
 
     def testGetRedundantMatrix(self):
         if 'aijcrl' in self.A.getType(): return # duplicate not supported
+        if 'mpisbaij' in self.A.getType(): return # not working
         self._preallocate()
         self._set_values_ijv()
         self.A.assemble()
