@@ -247,6 +247,19 @@ class TestObjectAOMapping(BaseTestObject, unittest.TestCase):
     FACTORY = 'createMapping'
     TARGS = ([], [])
 
+# class TestObjectFE(BaseTestObject, unittest.TestCase):
+#     CLASS  = PETSc.FE
+#     FACTORY = 'create'
+#
+# class TestObjectQuad(BaseTestObject, unittest.TestCase):
+#     CLASS  = PETSc.Quad
+#     FACTORY = 'create'
+
+class TestObjectDMLabel(BaseTestObject, unittest.TestCase):
+    CLASS  = PETSc.DMLabel
+    FACTORY = 'create'
+    TARGS = ("test",)
+
 # --------------------------------------------------------------------
 
 import numpy
